@@ -2,7 +2,7 @@
  * ====                   FRACTAL GRAPHICS GENERATOR                     ====
  * ==========================================================================
  *
- * Copyright (C) 2003-2025 by Thomas Dreibholz
+ * Copyright (C) 2003-2026 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -269,9 +269,14 @@ bool FractalGeneratorDoc::saveDocument(const QString& fileName)
       newFileName += QStringLiteral(".fsf");
    }
    QFile file(newFileName);
-   file.open(QIODevice::WriteOnly);
-   file.write(doc.toString().toLocal8Bit());
-   setFileName(newFileName);
+   if(file.open(QIODevice::WriteOnly)) {
+      file.write(doc.toString().toLocal8Bit());
+      setFileName(newFileName);
+   }
+   else {
+      showError(tr("Save File Failure"),
+                newFileName);
+   }
 
    Modified = false;
    return true;
