@@ -2,7 +2,7 @@
  * ====                   FRACTAL GRAPHICS GENERATOR                     ====
  * ==========================================================================
  *
- * Copyright (C) 2003-2025 by Thomas Dreibholz
+ * Copyright (C) 2003-2026 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ int main(int argc, char *argv[])
    if(!applicationTranslator.load(QLatin1String("fractgen_") + QLocale::system().name())) {
       if(!applicationTranslator.load(QLatin1String("fractgen_") + QLocale::system().name(),
                                      QStringLiteral(FRACTGEN_INSTALL_PREFIX) + QStringLiteral("/share/fractgen"))) {
-         puts("Failed to load translations!");
+         // No translations for this locale -> using built-in strings.
       }
    }
    application.installTranslator(&applicationTranslator);
